@@ -1,6 +1,6 @@
 
 /*
- * $Id: client_side.c,v 1.90.2.10 1997/07/09 16:48:32 wessels Exp $
+ * $Id: client_side.c,v 1.90.2.13 1997/07/11 00:00:14 wessels Exp $
  *
  * DEBUG: section 33    Client-side Routines
  * AUTHOR: Duane Wessels
@@ -284,7 +284,7 @@ clientRedirectDone(void *data, char *result)
 	urlCanonical(icpState->request, icpState->url);
     }
     icpParseRequestHeaders(icpState);
-    fd_note(fd, icpState->url);
+    fd_note(fd, icpState->log_url);
     if (!BIT_TEST(icpState->request->flags, REQ_PROXY_KEEPALIVE)) {
 	commSetSelect(fd,
 	    COMM_SELECT_READ,
@@ -443,11 +443,11 @@ icpProcessExpired(int fd, void *data)
     BIT_SET(icpState->request->flags, REQ_REFRESH);
     icpState->old_entry = icpState->entry;
     entry = storeCreateEntry(url,
+	icpState->log_url,
 	request_hdr,
 	icpState->req_hdr_sz,
 	icpState->request->flags,
 	icpState->method);
-    storeSetLogUrl(entry, icpState->request);
     /* NOTE, don't call storeLockObject(), storeCreateEntry() does it */
     storeClientListAdd(entry, fd, 0);
     storeClientListAdd(icpState->old_entry, fd, 0);
