@@ -1,5 +1,5 @@
 /*
- * $Id: url.h,v 1.40.2.2 1997/07/05 22:15:29 wessels Exp $
+ * $Id: url.h,v 1.40.2.4 1997/07/10 23:42:22 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -82,7 +82,8 @@ extern method_t urlParseMethod _PARAMS((const char *));
 extern void urlInitialize _PARAMS((void));
 extern request_t *urlParse _PARAMS((method_t, char *));
 extern char *urlCanonical _PARAMS((const request_t *, char *));
-extern char *urlNoLogin _PARAMS((const request_t *, char *));
+extern char *urlCanonicalClean _PARAMS((const request_t *));
+extern char *urlClean _PARAMS((char *));
 extern request_t *requestLink _PARAMS((request_t *));
 extern void requestUnlink _PARAMS((request_t *));
 extern int matchDomainName _PARAMS((const char *d, const char *h));
